prai 🙏
===========
Raiblocks Python RPC client

Install
-------
A somewhat stable version from pypi:

.. code-block:: bash

    $ pip install prai

Or the most recent master version from Github:

.. code-block:: bash

    $ git clone https://github.com/jxub/prai

Some notes
----------
Prai is a work in progress, so expect some rough edges and stay tuned for updates 🙈.

Roadmap
-------
- Finish basic API.
- Add some higher-level features, for example a simple e-commerce payment API.
- Add more validation and tests (ughhh).
- A simple tutorial in this very README.
🍻 


